import { XDocument } from './XDocument';
import { IOccurrence, ITextRange } from './texton';
export interface XText extends Text {
    startPosition: number;
    endPosition: number;
}
export declare class XSelection {
    readonly range: Range;
    private readonly xDocument;
    private xTexts;
    constructor(range: Range, xDocument: XDocument);
    /**
     * create {@link XSelection} from native {@link Selection}
     * @param selection the native `Selection` from which to create the `XSelection` instance.
     * @param xDoc the context of the to be created `XSelection` instance.
     */
    static fromSelection(selection: Selection, xDoc: XDocument): XSelection | null;
    /**
     * create {@link XSelection} from {@link ITextRange} pojo;
     * {@link ITextRange} specifies the start point and end point
     * <pre>
     * export interface ITextRange {
     *   from: { text: string, nth: number }, // means starting from the `nth` `text`
     *   to: { text: string, nth: number }, // means ending at the `nth` `text`
     * }
     * </pre>
     * @param textRange the serialized pojo from which to create the `XSelection` instance.
     * @param optSelect true to create explicit selection(be selected visibly from browser), false otherwise
     * @param xDoc the context of the to be created `XSelection` instance.
     */
    static fromTextRange(textRange: ITextRange, optSelect: boolean | undefined, xDoc: XDocument): XSelection | null;
    /**
     * create {@link XSelection} from {@link ITextRange} pojo
     * @param text the text content to be selected.
     * @param nth together with {@param text} specifies the exact {@code nth} {@code text} will be used to create the selection.
     * @param optSelect true to create explicit selection(be selected visibly from browser), false otherwise
     * @param xDoc the context of the to be created `XSelection` instance.
     */
    static fromText(text: string, nth: number | undefined, optSelect: boolean | undefined, xDoc: XDocument): XSelection | null;
    /**
     * create {@link XSelection} from native {@link Range}
     * @param range the text content to be selected.
     * @param optSelect true to create selection explicitly(be selected visibly from browser), false otherwise
     * @param xDoc the context of the to be created `XSelection` instance.
     */
    static fromRange(range: Range | null, optSelect: boolean | undefined, xDoc: XDocument): XSelection | null;
    private static rangeFromSelection;
    private static rangeFromTextRange;
    /**
     *  return an empty range object that has both of its boundary points positioned at
     *  the beginning of the document when no parameters are given, else return an range
     *  object that contains the nth occurrence of the specified text
     *
     * @param {string} text the base text
     * @param {number} nth = 1 the nth index
     * @param {XDocument} xDoc
     * @return {Range} the range created that contains the specified text
     * @private
     */
    private static rangeFromText;
    /**
     * the text nodes contained in the selection.
     * <em>
     * text node will be splatted into 2 parts if the selection is start from/end in a internal
     * position of a text node
     * </em>
     */
    readonly texts: Text[];
    /**
     * get the exact "occurrence" of this selection.
     * <em>
     *   the selected text content may appear >=1 times in this page, and the selection is it's
     *   {@code occurrence.nth} time. and the start char of this selection is the
     *   {@code occurrence.position}th char of the whole text content in this page.
     * </em>
     *
     */
    getOccurrence(): IOccurrence;
    /**
     * get the text range of the selection in this page.
     * <pre>
     * export interface ITextRange {
     *   from: { text: string, nth: number }, // means starting from the `nth` `text`
     *   to: { text: string, nth: number }, // means ending at the `nth` `text`
     * }
     * </pre>
     * that is, the text content of this selection starts with {@code textRange.from.text} and
     * ends with {@code textRange.to.text}. and {@code textRange.from.text} is its {@code textRange.from.nth}
     * occurrence, {@code textRange.to.text} is its {@code textRange.to.nth} occurrence.
     * e.g.
     * for text
     * <span>hello world, hello miller, hello world, hello miller, hello miller</span>
     * <pre>
     * {
     *   from:{text: 'hello', nth: 2}
     *   to:{text: 'miller', nth: 3}
     * }
     * means, the selection starts from the 2nd `hello` and ends with 3rd `miller`. that is:
     * <span>hello world, <selected>hello miller, hello world, hello miller, hello miller<selected>, hello world<span>
     * </pre>
     *
     * @param len
     */
    getTextRange(len?: number): ITextRange;
    /**
     * get the selected text content
     * @param compact true to remove the white spaces. false otherwise
     */
    getContent(compact?: boolean): string;
    /**
     * get the native selection
     */
    readonly selection: Selection;
    /**
     * clear the selection
     */
    empty(): void;
    /**
     * check if the selection is cleared or not.
     */
    isEmpty(): boolean;
    cancel(): void;
}
